@@ -59,7 +59,7 @@ Q_SIGNALS:
      * @param collectionUrl The URL of the discovered collection
      * @param configuredUrl The URL given to the job
      */
-    void collectionDiscovered(int protocol, const QString &collectionUrl, const QString &configuredUrl);
+    void collectionDiscovered(KDAV::Protocol protocol, const QString &collectionUrl, const QString &configuredUrl);
 
 private:
     void principalFetchFinished(KJob *);
