@@ -1,24 +1,13 @@
 /*
-    Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>
+    SPDX-FileCopyrightText: 2016 Sandro Knauß <sknauss@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDAV_DAVERROR_H
 #define KDAV_DAVERROR_H
 
-#include "kpimkdav_export.h"
+#include "kdav_export.h"
 
 #include <KJob>
 
@@ -49,7 +38,7 @@ enum ErrorNumber {
 class ErrorPrivate;
 
 /** DAV operation error. */
-class KPIMKDAV_EXPORT Error
+class KDAV_EXPORT Error
 {
 public:
     explicit Error();
